==> gemforged-3.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/item/GemforgedItemGroups.java <==
package net.trique.gemforged.item;

import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import net.trique.gemforged.Gemforged;
import net.trique.gemforged.block.GemforgedBlocks;

public class GemforgedItemGroups {
    public static final class_1761 GEMFORGED_GROUP = class_2378.method_10230(class_7923.field_44687,
            new class_2960(Gemforged.MOD_ID, "gemforged"),
            FabricItemGroup.builder()
                    .method_47321(class_2561.method_43471("gemforged.tab"))
                    .method_47320(() -> new class_1799(GemforgedItems.BATTLE_CHARM))
                    .method_47317((displayContext, entries) -> {
                        entries.method_45421(GemforgedBlocks.RANDOM_GEM_VEIN);
                        entries.method_45421(GemforgedBlocks.DEEPSLATE_RANDOM_GEM_VEIN);
                        entries.method_45421(GemforgedBlocks.BLOODSTONE_BLOCK);
                        entries.method_45421(GemforgedBlocks.PHOENIXTONE_BLOCK);
                        entries.method_45421(GemforgedBlocks.SOLARIUM_BLOCK);
                        entries.method_45421(GemforgedBlocks.VERDANTITE_BLOCK);
                        entries.method_45421(GemforgedBlocks.VENOMYTE_BLOCK);
                        entries.method_45421(GemforgedBlocks.PRISMYTE_BLOCK);
                        entries.method_45421(GemforgedBlocks.NYXITE_BLOCK);
                        entries.method_45421(GemforgedBlocks.GRAVITIUM_BLOCK);

                        entries.method_45421(GemforgedItems.BATTLE_CHARM);
                        entries.method_45421(GemforgedItems.PHOENIX_CHARM);
                        entries.method_45421(GemforgedItems.SANDBURST_STAFF);
                        entries.method_45421(GemforgedItems.VERDANT_TOTEM);
                        entries.method_45421(GemforgedItems.VENOMFANG_BLADE);
                        entries.method_45421(GemforgedItems.THUNDER_PRISM);
                        entries.method_45421(GemforgedItems.SHADOWSTEP_DAGGER);
                        entries.method_45421(GemforgedItems.GRAVITY_HORN);

                        entries.method_45421(GemforgedItems.BLOODSTONE);
                        entries.method_45421(GemforgedItems.PHOENIXTONE);
                        entries.method_45421(GemforgedItems.SOLARIUM);
                        entries.method_45421(GemforgedItems.VERDANTITE);
                        entries.method_45421(GemforgedItems.VENOMYTE);
                        entries.method_45421(GemforgedItems.PRISMYTE);
                        entries.method_45421(GemforgedItems.NYXITE);
                        entries.method_45421(GemforgedItems.GRAVITIUM);

                        entries.method_45421(GemforgedItems.CHARM_TEMPLATE);
                        entries.method_45421(GemforgedItems.STAFF_TEMPLATE);
                        entries.method_45421(GemforgedItems.TOTEM_TEMPLATE);
                        entries.method_45421(GemforgedItems.BLADE_TEMPLATE);
                        entries.method_45421(GemforgedItems.PRISM_TEMPLATE);
                        entries.method_45421(GemforgedItems.DAGGER_TEMPLATE);
                        entries.method_45421(GemforgedItems.HORN_TEMPLATE);
                    }).method_47324());

    public static void registerItemGroups() {
        Gemforged.LOGGER.info("Registering Item Groups for " + Gemforged.MOD_ID);
    }
}

==> gemforged-4.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/item/GemforgedItemGroups.java <==
package net.trique.gemforged.item;

import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import net.trique.gemforged.Gemforged;
import net.trique.gemforged.block.GemforgedBlocks;

public class GemforgedItemGroups {
    public static final class_1761 GEMFORGED_GROUP = class_2378.method_10230(class_7923.field_44687,
            new class_2960(Gemforged.MOD_ID, "gemforged"),
            FabricItemGroup.builder()
                    .method_47321(class_2561.method_43471("gemforged.tab"))
                    .method_47320(() -> new class_1799(GemforgedItems.BATTLE_CHARM))
                    .method_47317((displayContext, entries) -> {
                        entries.method_45421(GemforgedBlocks.RANDOM_GEM_VEIN);
                        entries.method_45421(GemforgedBlocks.DEEPSLATE_RANDOM_GEM_VEIN);
                        entries.method_45421(GemforgedBlocks.BLOODSTONE_BLOCK);
                        entries.method_45421(GemforgedBlocks.PHOENIXTONE_BLOCK);
                        entries.method_45421(GemforgedBlocks.SOLARIUM_BLOCK);
                        entries.method_45421(GemforgedBlocks.VERDANTITE_BLOCK);
                        entries.method_45421(GemforgedBlocks.VENOMYTE_BLOCK);
                        entries.method_45421(GemforgedBlocks.PRISMYTE_BLOCK);
                        entries.method_45421(GemforgedBlocks.NYXITE_BLOCK);
                        entries.method_45421(GemforgedBlocks.GRAVITIUM_BLOCK);

                        entries.method_45421(GemforgedItems.BATTLE_CHARM);
                        entries.method_45421(GemforgedItems.PHOENIX_CHARM);
                        entries.method_45421(GemforgedItems.PHOENIXFIRE_STAFF);
                        entries.method_45421(GemforgedItems.SANDBURST_STAFF);
                        entries.method_45421(GemforgedItems.VERDANT_TOTEM);
                        entries.method_45421(GemforgedItems.VENOMFANG_BLADE);
                        entries.method_45421(GemforgedItems.GLACIAL_CHARM);
                        entries.method_45421(GemforgedItems.THUNDER_PRISM);
                        entries.method_45421(GemforgedItems.GHOST_BOW);
                        entries.method_45421(GemforgedItems.SHADOWSTEP_DAGGER);
                        entries.method_45421(GemforgedItems.GRAVITY_HORN);

                        entries.method_45421(GemforgedItems.BLOODSTONE);
                        entries.method_45421(GemforgedItems.PHOENIXTONE);
                        entries.method_45421(GemforgedItems.SOLARIUM);
                        entries.method_45421(GemforgedItems.VERDANTITE);
                        entries.method_45421(GemforgedItems.VENOMYTE);
                        entries.method_45421(GemforgedItems.PRISMYTE);
                        entries.method_45421(GemforgedItems.NYXITE);
                        entries.method_45421(GemforgedItems.GRAVITIUM);

                        entries.method_45421(GemforgedItems.CHARM_TEMPLATE);
                        entries.method_45421(GemforgedItems.STAFF_TEMPLATE);
                        entries.method_45421(GemforgedItems.TOTEM_TEMPLATE);
                        entries.method_45421(GemforgedItems.BLADE_TEMPLATE);
                        entries.method_45421(GemforgedItems.PRISM_TEMPLATE);
                        entries.method_45421(GemforgedItems.BOW_TEMPLATE);
                        entries.method_45421(GemforgedItems.DAGGER_TEMPLATE);
                        entries.method_45421(GemforgedItems.HORN_TEMPLATE);
                    }).method_47324());

    public static void registerItemGroups() {
        Gemforged.LOGGER.info("Registering Item Groups for " + Gemforged.MOD_ID);
    }
}
